@@ -23,7 +23,7 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class CreateVerifySDKRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'CreateVerifySDK')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'CreateVerifySDK','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -40,16 +40,4 @@ class CreateVerifySDKRequest(RpcRequest):
 		return self.get_query_params().get('Platform')
 
 	def set_Platform(self,Platform):
-		self.add_query_param('Platform',Platform)
-
-	def get_SourceIp(self):
-		return self.get_query_params().get('SourceIp')
-
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Lang(self):
-		return self.get_query_params().get('Lang')
-
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+		self.add_query_param('Platform',Platform)
\ No newline at end of file
